"use strict";

exports.__esModule = true;

var _noImportant = require("aphrodite/no-important");

var aphrodite = _interopRequireWildcard(_noImportant);

var _getHairlineWidth = require("./getHairlineWidth");

var _getHairlineWidth2 = _interopRequireDefault(_getHairlineWidth);

var _modality = require("./modality");

var _modality2 = _interopRequireDefault(_modality);

var _processStyles = require("./processStyles");

var _processStyles2 = _interopRequireDefault(_processStyles);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

// initialize focus-ring fix
(0, _modality2.default)();

var absoluteFillObject = {
  position: "absolute",
  left: 0,
  right: 0,
  top: 0,
  bottom: 0
};

var isObject = function isObject(value) {
  return Object.prototype.toString.call(value) === "[object Object]";
};

var process = function process(styles) {
  var processedStyles = (0, _processStyles2.default)(styles);
  Object.keys(processedStyles).forEach(function (key) {
    var value = processedStyles[key];
    if (isObject(value)) {
      processedStyles[key] = process(value);
    }
  });
  return processedStyles;
};

var create = function create(styles) {
  return aphrodite.StyleSheet.create(process(styles));
};

var flatten = function flatten(arr) {
  return arr.reduce(function (flat, toFlatten) {
    return flat.concat(Array.isArray(toFlatten) ? flatten(toFlatten) : toFlatten);
  }, []);
};

var extractInlineStyles = function extractInlineStyles(styleArray) {
  var styles = [];
  var inlineStyles = {};
  var flattendStyles = flatten(styleArray);
  flattendStyles.forEach(function (style) {
    if (!style) {
      return;
    } else if (style._name) {
      styles.push(style);
    } else {
      Object.assign(inlineStyles, style);
    }
  });
  return { styles: styles, inlineStyles: inlineStyles };
};

var StyleSheet = {
  absoluteFill: create(absoluteFillObject),
  absoluteFillObject: absoluteFillObject,
  compose: function compose(style1, style2) {
    if (style1 && style2) {
      return [style1, style2];
    } else {
      return style1 || style2;
    }
  },

  create: create,
  hairlineWidth: (0, _getHairlineWidth2.default)(),
  resolve: function resolve(styleArray) {
    var _extractInlineStyles = extractInlineStyles(styleArray),
        styles = _extractInlineStyles.styles,
        inlineStyles = _extractInlineStyles.inlineStyles;

    return {
      className: aphrodite.css(styles),
      style: inlineStyles
    };
  }
};

exports.default = StyleSheet;
module.exports = exports["default"];