"use strict";

exports.__esModule = true;

var _AccessibilityUtil = require("../AccessibilityUtil");

var _AccessibilityUtil2 = _interopRequireDefault(_AccessibilityUtil);

var _StyleSheet = require("../../StyleSheet");

var _StyleSheet2 = _interopRequireDefault(_StyleSheet);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var emptyObject = {};

var resetStyles = _StyleSheet2.default.create({
  ariaButton: {
    cursor: "pointer"
  },
  button: {
    appearance: "none",
    backgroundColor: "transparent",
    color: "inherit",
    font: "inherit",
    textAlign: "inherit"
  },
  heading: {
    font: "inherit"
  },
  link: {
    backgroundColor: "transparent",
    color: "inherit",
    textDecorationLine: "none"
  },
  list: {
    listStyle: "none"
  }
});

var createDOMProps = function createDOMProps(component, props) {
  if (!props) {
    props = emptyObject;
  }

  var _props = props,
      accessibilityLabel = _props.accessibilityLabel,
      accessibilityLiveRegion = _props.accessibilityLiveRegion,
      importantForAccessibility = _props.importantForAccessibility,
      providedStyle = _props.style,
      testID = _props.testID,
      accessible = _props.accessible,
      accessibilityRole = _props.accessibilityRole,
      domProps = _objectWithoutProperties(_props, ["accessibilityLabel", "accessibilityLiveRegion", "importantForAccessibility", "style", "testID", "accessible", "accessibilityRole"]);

  var isDisabled = _AccessibilityUtil2.default.isDisabled(props);
  var role = accessibilityRole;
  var tabIndex = _AccessibilityUtil2.default.propsToTabIndex(props);
  var styleArray = [component === "a" && resetStyles.link, component === "button" && resetStyles.button, role === "heading" && resetStyles.heading, component === "ul" && resetStyles.list, role === "button" && !isDisabled && resetStyles.ariaButton, providedStyle];

  var _StyleSheet$resolve = _StyleSheet2.default.resolve(styleArray),
      className = _StyleSheet$resolve.className,
      style = _StyleSheet$resolve.style;

  if (isDisabled) {
    domProps["aria-disabled"] = true;
  }
  if (importantForAccessibility === "no-hide-descendants") {
    domProps["aria-hidden"] = true;
  }
  if (accessibilityLabel && accessibilityLabel.constructor === String) {
    domProps["aria-label"] = accessibilityLabel;
  }
  if (accessibilityLiveRegion && accessibilityLiveRegion.constructor === String) {
    domProps["aria-live"] = accessibilityLiveRegion === "none" ? "off" : accessibilityLiveRegion;
  }
  if (className && className.constructor === String) {
    domProps.className = domProps.className ? domProps.className + " " + className : className;
  }
  if (component === "a" && domProps.target === "_blank") {
    domProps.rel = (domProps.rel || "") + " noopener noreferrer";
  }
  if (role && role.constructor === String && role !== "label") {
    domProps.role = role;
  }
  if (style) {
    domProps.style = style;
  }
  if (tabIndex) {
    domProps.tabIndex = tabIndex;
  }
  if (testID && testID.constructor === String) {
    domProps["data-testid"] = testID;
  }

  return domProps;
};

exports.default = createDOMProps;
module.exports = exports["default"];